==> gnokii-0.6.2.tar.gz: gnokii-0.6.2/include/gnokii/networks.h <==
/*

  $Id: networks.h,v 1.10 2003/03/06 22:32:29 pkot Exp $

  G N O K I I

  A Linux/Unix toolset and driver for Nokia mobile phones.

  This file is part of gnokii.

  Gnokii is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  Gnokii is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with gnokii; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

  Copyright (C) 1999, 2000 Hugh Blemings & Pavel Jank ml.

  Header file for GSM networks.

*/

#ifndef _gnokii_networks_h
#define _gnokii_networks_h

/* This type is used to hold information about various GSM networks. */
typedef struct {
	char *code; /* GSM network code */
	char *name; /* GSM network name */
} gn_network;

/* This type is used to hold information about various GSM countries. */
typedef struct {
	char *code; /* GSM country code */
	char *name; /* GSM country name */
} gn_country;

API char *gn_network_name_get(char *network_code);
API char *gn_network_code_get(char *network_name);

API char *gn_country_name_get(char *country_code);
API char *gn_country_code_get(char *country_name);

API int gn_network_get(gn_network *network, int index);
API int gn_country_get(gn_country *country, int index);

#endif	/* _gnokii_networks_h */

==> gnokii_0.6.8.orig.tar.gz: gnokii-0.6.8/include/gnokii/networks.h <==
/*

  $Id: networks.h,v 1.13 2005/04/24 19:41:23 pkot Exp $

  G N O K I I

  A Linux/Unix toolset and driver for the mobile phones.

  This file is part of gnokii.

  Gnokii is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  Gnokii is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with gnokii; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

  Copyright (C) 1999-2000 Hugh Blemings & Pavel Jank ml.
  Copyright (C) 2002      Pawel Kot

  Header file for GSM networks.

*/

#ifndef _gnokii_networks_h
#define _gnokii_networks_h

/* This type is used to hold information about various GSM networks. */
typedef struct {
	char *code; /* GSM network code */
	char *name; /* GSM network name */
} gn_network;

/* This type is used to hold information about various GSM countries. */
typedef struct {
	char *code; /* GSM country code */
	char *name; /* GSM country name */
} gn_country;

API char *gn_network_name_get(char *network_code);
API char *gn_network_code_get(char *network_name);
API char *gn_network_code_find(char *network_name, char *country_name);

API char *gn_country_name_get(char *country_code);
API char *gn_country_code_get(char *country_name);

API int gn_network_get(gn_network *network, int index);
API int gn_country_get(gn_country *country, int index);

API char *gn_network2country(char *network);

#endif	/* _gnokii_networks_h */
